# pynocturnal
Pynocturnal is a python library for lunar information

<br>
<h1>Usage:</h1>:
<br>

```python

    # create instance of myMoon
    moon = myMoon()
    
    # functions
    phase = moon.get_lunar_phase() # returns lunar phase
    age = moon.get_lunar_age() # returns lunar age
    percent = moon.get_lunar_age_percent() # returns percent of lunar age
```
    
    
